# Generated by Django 3.1.10 on 2022-02-04 11:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DownloadSite',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('link_key', models.CharField(editable=False, max_length=63, unique=True)),
                ('timestamp_creation', models.DateTimeField(auto_now_add=True, verbose_name='creation time')),
            ],
            options={
                'verbose_name': 'Download Site',
            },
        ),
        migrations.CreateModel(
            name='UploadFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('display_name', models.CharField(max_length=63, unique=True, verbose_name='Display Name')),
                ('file', models.FileField(help_text='Select the file to upload', max_length=255, upload_to='', verbose_name='file')),
            ],
            options={
                'verbose_name': 'Upload File',
            },
        ),
        migrations.CreateModel(
            name='Download',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True, verbose_name='is active')),
                ('link_key', models.CharField(editable=False, max_length=63, unique=True)),
                ('timestamp_creation', models.DateTimeField(auto_now_add=True, verbose_name='creation time')),
                ('down_file', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='downloads', to='onetimelink.uploadfile')),
                ('site', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='downloads', to='onetimelink.downloadsite')),
            ],
        ),
    ]
