{% extends 'admin/change_list.html' %}

{% block object-tools %}
    <div>
        <form action="downloadsite/" method="POST">
            {% csrf_token %}
            <button type="submit" class="btn btn-primary">Make Download Site</button>
        </form>
    </div>
    <br />
    {{ block.super }}
{% endblock %}